/*
 * Copyright © 2011 Keith Packard <keithp@keithp.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 */

package org.altusmetrum.altoslib_12;


public class AltosTelemetryMetrumData extends AltosTelemetryStandard {

	int	ground_pres() { return int32(8); }
	int	ground_accel() { return int16(12); }
	int	accel_plus_g() { return int16(14); }
	int	accel_minus_g() { return int16(16); }

	public AltosTelemetryMetrumData(int[] bytes) throws AltosCRCException {
		super(bytes);
	}

	public void provide_data(AltosDataListener listener, AltosCalData cal_data) {
		cal_data.set_ground_accel(ground_accel());
		cal_data.set_accel_plus_minus(accel_plus_g(), accel_minus_g());
		cal_data.set_ground_pressure(ground_pres());
	}
}
